@@ -31,6 +31,7 @@ L = threading.Lock()
 Q = queue.Queue()
 logging.basicConfig(format='%(asctime)s - %(levelname)s: %(message)s', level=logging.INFO)
 requests.packages.urllib3.disable_warnings()
+adapter = requests.adapters.HTTPAdapter(pool_connections=1000, pool_maxsize=1000)
 
 
 class CJsonEncoder(json.JSONEncoder):
@@ -70,16 +71,15 @@ def async_(f):
     return wrapper
 
 
-def cache(seconds=0, is_update=None):
-
+def cache(seconds=0, is_update=None, redis_db=redis_db):
     @wrapt.decorator
     def wrapper(wrapped, instance, args, kwargs):
         # 将实参进行md5作为key
         md5 = hashlib.md5()
-        md5.update(bytes("%s"%(args), encoding='utf-8'))
+        md5.update(bytes("%s" % (args), encoding='utf-8'))
         key = md5.hexdigest()
         func_name = wrapped.__name__
-        key = "%s:%s"%(func_name, key)
+        key = "%s:%s" % (func_name, key)
 
         # 如果不更新则直接走缓存
         if not is_update:
@@ -134,6 +134,8 @@ class Tool:
             self.session = requests
         else:
             self.session = requests.session()
+            self.session.mount('http://', adapter)
+            self.session.mount('https://', adapter)
         if is_proxy_pool:
             self.update_proxy_pool()
             while True:
@@ -607,7 +609,7 @@ class Tool:
         chrome_options = webdriver.ChromeOptions()
         if not is_onload_img:
             prefs = {"profile.managed_default_content_settings.images": 2, 'permissions.default.stylesheet': 2}
-            chrome_options.add_argument("user-data-dir=C:\\Users\Administrator\AppData\Local\Google\Chrome\\User Data")
+            # chrome_options.add_argument("user-data-dir=C:\\Users\Administrator\AppData\Local\Google\Chrome\\User Data")
             chrome_options.add_experimental_option("prefs", prefs)
         driver = webdriver.Chrome(path, chrome_options=chrome_options)
         return driver
